@@ -38,6 +38,9 @@
 # include "config.h"
 #endif	/* HAVE_CONFIG_H */
 /* for fgetln() */
+#if !defined __BSD_VISIBLE
+# define __BSD_VISIBLE 1
+#endif /* !__BSD_VISIBLE */
 #if !defined _NETBSD_SOURCE
 # define _NETBSD_SOURCE
 #endif	/* !_NETBSD_SOURCE */
@@ -143,16 +146,6 @@ error(const char *fmt, ...)
 	return;
 }
 
-static inline __attribute__((unused)) void*
-deconst(const void *cp)
-{
-	union {
-		const void *c;
-		void *p;
-	} tmp = {cp};
-	return tmp.p;
-}
-
 static inline __attribute__((always_inline)) unsigned int
 yfls(unsigned int x)
 {
