@@ -68,7 +68,7 @@
 # undef WITH_LEAP_SECONDS
 #endif	/* SKIP_LEAP_ARITH */
 #if defined WITH_LEAP_SECONDS
-# include "leapseconds.h"
+# include "leap-seconds.h"
 #endif	/* WITH_LEAP_SECONDS */
 
 #if defined __INTEL_COMPILER
@@ -126,24 +126,22 @@ static inline dt_ssexy_t
 __to_unix_epoch(struct dt_dt_s dt)
 {
 /* daisy is competing with the prevalent unix epoch, this is the offset */
+	struct dt_d_s dd;
+	dt_ssexy_t res;
+
 	if (dt.typ == DT_SEXY) {
 		/* no way to find out, is there */
 		return dt.sexy;
 	} else if (dt_sandwich_p(dt) || dt_sandwich_only_d_p(dt)) {
-		dt_daisy_t d = dt_conv_to_daisy(dt.d);
-		dt_ssexy_t res = (d - DAISY_UNIX_BASE) * SECS_PER_DAY;
-		if (dt_sandwich_p(dt)) {
-			res += (dt.t.hms.h * 60 + dt.t.hms.m) * 60 + dt.t.hms.s;
-		}
-		return res;
+		dd = dt.d;
 	} else if (dt_sandwich_only_t_p(dt)) {
-		/* bug/65, fill in with base */
-		dt_daisy_t d = dt_conv_to_daisy(dt_get_base().d);
-		dt_ssexy_t res = (d - DAISY_UNIX_BASE) * SECS_PER_DAY;
-		res += (dt.t.hms.h * 60 + dt.t.hms.m) * 60 + dt.t.hms.s;
-		return res;
+		dd = dt_get_base().d;
+	} else {
+		return 0;
 	}
-	return 0;
+	res = (dt_conv_to_daisy(dd) - DAISY_UNIX_BASE) * SECS_PER_DAY;
+	res += (dt.t.hms.h * 60 + dt.t.hms.m) * 60 + dt.t.hms.s;
+	return res;
 }
 
 /* public version */
@@ -1497,12 +1495,6 @@ dt_dtadd(struct dt_dt_s d, struct dt_dtdur_s dur)
 	}
 #endif	/* WITH_LEAP_SECONDS */
 
-	if (UNLIKELY(dur.durtyp == DT_DURM && dt_sandwich_only_d_p(d))) {
-		/* probably +/-[n]m where `m' was meant to be `mo' */
-		dur.d.durtyp = DT_DURMO;
-		dur.d.dv = dur.dv;
-	}
-
 	if (d.typ == DT_SEXY) {
 		d.sexy = __sexy_add(d.sexy, dur);
 		return d;
