@@ -1,6 +1,6 @@
 /*** time-core-strpf.c -- parser and formatter funs for time-core
  *
- * Copyright (C) 2011-2016 Sebastian Freundt
+ * Copyright (C) 2011-2018 Sebastian Freundt
  *
  * Author:  Sebastian Freundt <freundt@ga-group.nl>
  *
@@ -133,12 +133,13 @@ __strpt_card(struct strpt_s *d, const char *str, struct dt_spec_s s, char **ep)
 	case DT_SPFL_S_AMPM: {
 		const unsigned int casebit = 0x20;
 
+		d->flags.am_pm_bit = 1;
 		if ((sp[0] | casebit) == 'a' &&
 		    (sp[1] | casebit) == 'm') {
-			;
+			d->flags.pm_p = 0;
 		} else if ((sp[0] | casebit) == 'p' &&
 			   (sp[1] | casebit) == 'm') {
-			d->flags.am_pm_bit = 1;
+			d->flags.pm_p = 1;
 		} else {
 			goto fucked;
 		}
@@ -246,13 +247,12 @@ __strft_card(
 		if (UNLIKELY(!s.cap)) {
 			casebit = 0x20;
 		}
-		if (d->h >= 12) {
+		if (d->h >= 12 && d->h < 24) {
 			buf[res++] = (char)('P' | casebit);
-			buf[res++] = (char)('M' | casebit);
 		} else {
 			buf[res++] = (char)('A' | casebit);
-			buf[res++] = (char)('M' | casebit);
 		}
+		buf[res++] = (char)('M' | casebit);
 		break;
 	}
 	case DT_SPFL_N_NANO:
