@@ -1,6 +1,6 @@
 /*** time-core-strpf.h -- parser and formatter funs for time-core
  *
- * Copyright (C) 2011-2016 Sebastian Freundt
+ * Copyright (C) 2011-2018 Sebastian Freundt
  *
  * Author:  Sebastian Freundt <freundt@ga-group.nl>
  *
@@ -50,8 +50,10 @@ struct strpt_s {
 	union {
 		unsigned int u;
 		struct {
-			/* 0 for am, 1 for pm */
+			/* whether am/pm indicator was given */
 			unsigned int am_pm_bit:1;
+			/* 0 for am, 1 for pm */
+			unsigned int pm_p:1;
 
 			unsigned int h_set:1;
 			unsigned int m_set:1;
